#[repr(C)]
pub struct semid_ds {
pub sem_perm: ipc_perm,
pub sem_otime: __time_t,
pub __sem_otime_high: __syscall_ulong_t,
pub sem_ctime: __time_t,
pub __sem_ctime_high: __syscall_ulong_t,
pub sem_nsems: __syscall_ulong_t,
pub __glibc_reserved3: __syscall_ulong_t,
pub __glibc_reserved4: __syscall_ulong_t,
}
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.